# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetVirtualInstanceResult',
    'AwaitableGetVirtualInstanceResult',
    'get_virtual_instance',
    'get_virtual_instance_output',
]

@pulumi.output_type
class GetVirtualInstanceResult:
    """
    A collection of values returned by getVirtualInstance.
    """
    def __init__(__self__, auto_suspend_seconds=None, current_size=None, default=None, description=None, desired_size=None, enable_remount_on_resume=None, id=None, mount_refresh_interval_seconds=None, name=None, state=None):
        if auto_suspend_seconds and not isinstance(auto_suspend_seconds, int):
            raise TypeError("Expected argument 'auto_suspend_seconds' to be a int")
        pulumi.set(__self__, "auto_suspend_seconds", auto_suspend_seconds)
        if current_size and not isinstance(current_size, str):
            raise TypeError("Expected argument 'current_size' to be a str")
        pulumi.set(__self__, "current_size", current_size)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if desired_size and not isinstance(desired_size, str):
            raise TypeError("Expected argument 'desired_size' to be a str")
        pulumi.set(__self__, "desired_size", desired_size)
        if enable_remount_on_resume and not isinstance(enable_remount_on_resume, bool):
            raise TypeError("Expected argument 'enable_remount_on_resume' to be a bool")
        pulumi.set(__self__, "enable_remount_on_resume", enable_remount_on_resume)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mount_refresh_interval_seconds and not isinstance(mount_refresh_interval_seconds, int):
            raise TypeError("Expected argument 'mount_refresh_interval_seconds' to be a int")
        pulumi.set(__self__, "mount_refresh_interval_seconds", mount_refresh_interval_seconds)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="autoSuspendSeconds")
    def auto_suspend_seconds(self) -> Optional[int]:
        """
        Number of seconds without queries after which the Virtual Instance is suspended.
        """
        return pulumi.get(self, "auto_suspend_seconds")

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> Optional[str]:
        """
        Virtual Instance current size.
        """
        return pulumi.get(self, "current_size")

    @property
    @pulumi.getter
    def default(self) -> Optional[bool]:
        """
        Virtual Instance name.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Virtual Instance description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="desiredSize")
    def desired_size(self) -> Optional[str]:
        """
        Virtual Instance desired size.
        """
        return pulumi.get(self, "desired_size")

    @property
    @pulumi.getter(name="enableRemountOnResume")
    def enable_remount_on_resume(self) -> Optional[bool]:
        """
        When a Virtual Instance is resumed, it will remount all collections that were mounted when the Virtual Instance was suspended.
        """
        return pulumi.get(self, "enable_remount_on_resume")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Virtual Instance id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mountRefreshIntervalSeconds")
    def mount_refresh_interval_seconds(self) -> Optional[int]:
        """
        Number of seconds between data refreshes for mounts on this Virtual Instance.
        """
        return pulumi.get(self, "mount_refresh_interval_seconds")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Virtual Instance name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        Virtual Instance state.
        """
        return pulumi.get(self, "state")


class AwaitableGetVirtualInstanceResult(GetVirtualInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVirtualInstanceResult(
            auto_suspend_seconds=self.auto_suspend_seconds,
            current_size=self.current_size,
            default=self.default,
            description=self.description,
            desired_size=self.desired_size,
            enable_remount_on_resume=self.enable_remount_on_resume,
            id=self.id,
            mount_refresh_interval_seconds=self.mount_refresh_interval_seconds,
            name=self.name,
            state=self.state)


def get_virtual_instance(auto_suspend_seconds: Optional[int] = None,
                         current_size: Optional[str] = None,
                         default: Optional[bool] = None,
                         description: Optional[str] = None,
                         desired_size: Optional[str] = None,
                         enable_remount_on_resume: Optional[bool] = None,
                         id: Optional[str] = None,
                         mount_refresh_interval_seconds: Optional[int] = None,
                         name: Optional[str] = None,
                         state: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVirtualInstanceResult:
    """
    Use this data source to access information about an existing resource.

    :param int auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
    :param str current_size: Virtual Instance current size.
    :param bool default: Virtual Instance name.
    :param str description: Virtual Instance description.
    :param str desired_size: Virtual Instance desired size.
    :param bool enable_remount_on_resume: When a Virtual Instance is resumed, it will remount all collections that were mounted when the Virtual Instance was suspended.
    :param str id: Virtual Instance id.
    :param int mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance.
    :param str name: Virtual Instance name.
    :param str state: Virtual Instance state.
    """
    __args__ = dict()
    __args__['autoSuspendSeconds'] = auto_suspend_seconds
    __args__['currentSize'] = current_size
    __args__['default'] = default
    __args__['description'] = description
    __args__['desiredSize'] = desired_size
    __args__['enableRemountOnResume'] = enable_remount_on_resume
    __args__['id'] = id
    __args__['mountRefreshIntervalSeconds'] = mount_refresh_interval_seconds
    __args__['name'] = name
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rockset:index/getVirtualInstance:getVirtualInstance', __args__, opts=opts, typ=GetVirtualInstanceResult).value

    return AwaitableGetVirtualInstanceResult(
        auto_suspend_seconds=pulumi.get(__ret__, 'auto_suspend_seconds'),
        current_size=pulumi.get(__ret__, 'current_size'),
        default=pulumi.get(__ret__, 'default'),
        description=pulumi.get(__ret__, 'description'),
        desired_size=pulumi.get(__ret__, 'desired_size'),
        enable_remount_on_resume=pulumi.get(__ret__, 'enable_remount_on_resume'),
        id=pulumi.get(__ret__, 'id'),
        mount_refresh_interval_seconds=pulumi.get(__ret__, 'mount_refresh_interval_seconds'),
        name=pulumi.get(__ret__, 'name'),
        state=pulumi.get(__ret__, 'state'))


@_utilities.lift_output_func(get_virtual_instance)
def get_virtual_instance_output(auto_suspend_seconds: Optional[pulumi.Input[Optional[int]]] = None,
                                current_size: Optional[pulumi.Input[Optional[str]]] = None,
                                default: Optional[pulumi.Input[Optional[bool]]] = None,
                                description: Optional[pulumi.Input[Optional[str]]] = None,
                                desired_size: Optional[pulumi.Input[Optional[str]]] = None,
                                enable_remount_on_resume: Optional[pulumi.Input[Optional[bool]]] = None,
                                id: Optional[pulumi.Input[str]] = None,
                                mount_refresh_interval_seconds: Optional[pulumi.Input[Optional[int]]] = None,
                                name: Optional[pulumi.Input[Optional[str]]] = None,
                                state: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVirtualInstanceResult]:
    """
    Use this data source to access information about an existing resource.

    :param int auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
    :param str current_size: Virtual Instance current size.
    :param bool default: Virtual Instance name.
    :param str description: Virtual Instance description.
    :param str desired_size: Virtual Instance desired size.
    :param bool enable_remount_on_resume: When a Virtual Instance is resumed, it will remount all collections that were mounted when the Virtual Instance was suspended.
    :param str id: Virtual Instance id.
    :param int mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance.
    :param str name: Virtual Instance name.
    :param str state: Virtual Instance state.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'DynamodbCollectionSource',
    'GcsCollectionSource',
    'GcsCollectionSourceCsv',
    'GcsCollectionSourceXml',
    'KafkaCollectionSource',
    'KafkaCollectionSourceStatus',
    'KafkaCollectionSourceStatusPartition',
    'KinesisCollectionSource',
    'MongodbCollectionSource',
    'QueryLambdaSql',
    'QueryLambdaSqlDefaultParameter',
    'RolePrivilege',
    'S3CollectionSource',
    'S3CollectionSourceCsv',
    'S3CollectionSourceXml',
    'GetAccountClusterResult',
]

@pulumi.output_type
class DynamodbCollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationName":
            suggest = "integration_name"
        elif key == "tableName":
            suggest = "table_name"
        elif key == "awsRegion":
            suggest = "aws_region"
        elif key == "scanEndTime":
            suggest = "scan_end_time"
        elif key == "scanRecordsProcessed":
            suggest = "scan_records_processed"
        elif key == "scanStartTime":
            suggest = "scan_start_time"
        elif key == "scanTotalRecords":
            suggest = "scan_total_records"
        elif key == "streamLastProcessedAt":
            suggest = "stream_last_processed_at"
        elif key == "useScanApi":
            suggest = "use_scan_api"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DynamodbCollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DynamodbCollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DynamodbCollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 integration_name: str,
                 table_name: str,
                 aws_region: Optional[str] = None,
                 rcu: Optional[int] = None,
                 scan_end_time: Optional[str] = None,
                 scan_records_processed: Optional[int] = None,
                 scan_start_time: Optional[str] = None,
                 scan_total_records: Optional[int] = None,
                 state: Optional[str] = None,
                 stream_last_processed_at: Optional[str] = None,
                 use_scan_api: Optional[bool] = None):
        """
        :param str integration_name: The name of the Rockset DynamoDB integration.
        :param str table_name: Name of DynamoDB table containing data.
        :param str aws_region: AWS region name of DynamoDB table, by default us-west-2 is used.
        :param int rcu: Max RCU usage for scan.
        :param str scan_end_time: DynamoDB scan end time.
        :param int scan_records_processed: Number of records inserted using scan.
        :param str scan_start_time: DynamoDB scan start time.
        :param int scan_total_records: Number of records in DynamoDB table at time of scan.
        :param str state: State of current ingest for this table.
        :param str stream_last_processed_at: ISO-8601 date when source was last processed.
        :param bool use_scan_api: Whether the initial table scan should use the DynamoDB scan API. If false, export will be performed using an S3 bucket.
        """
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "table_name", table_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if rcu is not None:
            pulumi.set(__self__, "rcu", rcu)
        if scan_end_time is not None:
            pulumi.set(__self__, "scan_end_time", scan_end_time)
        if scan_records_processed is not None:
            pulumi.set(__self__, "scan_records_processed", scan_records_processed)
        if scan_start_time is not None:
            pulumi.set(__self__, "scan_start_time", scan_start_time)
        if scan_total_records is not None:
            pulumi.set(__self__, "scan_total_records", scan_total_records)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stream_last_processed_at is not None:
            pulumi.set(__self__, "stream_last_processed_at", stream_last_processed_at)
        if use_scan_api is not None:
            pulumi.set(__self__, "use_scan_api", use_scan_api)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset DynamoDB integration.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> str:
        """
        Name of DynamoDB table containing data.
        """
        return pulumi.get(self, "table_name")

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[str]:
        """
        AWS region name of DynamoDB table, by default us-west-2 is used.
        """
        return pulumi.get(self, "aws_region")

    @property
    @pulumi.getter
    def rcu(self) -> Optional[int]:
        """
        Max RCU usage for scan.
        """
        return pulumi.get(self, "rcu")

    @property
    @pulumi.getter(name="scanEndTime")
    def scan_end_time(self) -> Optional[str]:
        """
        DynamoDB scan end time.
        """
        return pulumi.get(self, "scan_end_time")

    @property
    @pulumi.getter(name="scanRecordsProcessed")
    def scan_records_processed(self) -> Optional[int]:
        """
        Number of records inserted using scan.
        """
        return pulumi.get(self, "scan_records_processed")

    @property
    @pulumi.getter(name="scanStartTime")
    def scan_start_time(self) -> Optional[str]:
        """
        DynamoDB scan start time.
        """
        return pulumi.get(self, "scan_start_time")

    @property
    @pulumi.getter(name="scanTotalRecords")
    def scan_total_records(self) -> Optional[int]:
        """
        Number of records in DynamoDB table at time of scan.
        """
        return pulumi.get(self, "scan_total_records")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        State of current ingest for this table.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="streamLastProcessedAt")
    def stream_last_processed_at(self) -> Optional[str]:
        """
        ISO-8601 date when source was last processed.
        """
        return pulumi.get(self, "stream_last_processed_at")

    @property
    @pulumi.getter(name="useScanApi")
    def use_scan_api(self) -> Optional[bool]:
        """
        Whether the initial table scan should use the DynamoDB scan API. If false, export will be performed using an S3 bucket.
        """
        return pulumi.get(self, "use_scan_api")


@pulumi.output_type
class GcsCollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationName":
            suggest = "integration_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GcsCollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GcsCollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GcsCollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket: str,
                 format: str,
                 integration_name: str,
                 csv: Optional['outputs.GcsCollectionSourceCsv'] = None,
                 prefix: Optional[str] = None,
                 xml: Optional['outputs.GcsCollectionSourceXml'] = None):
        """
        :param str bucket: GCS bucket containing the target data.
        :param str format: Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        :param str integration_name: The name of the Rockset GCS integration.
        :param str prefix: Simple path prefix to GCS key.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        if csv is not None:
            pulumi.set(__self__, "csv", csv)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)
        if xml is not None:
            pulumi.set(__self__, "xml", xml)

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        GCS bucket containing the target data.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def format(self) -> str:
        """
        Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset GCS integration.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter
    def csv(self) -> Optional['outputs.GcsCollectionSourceCsv']:
        return pulumi.get(self, "csv")

    @property
    @pulumi.getter
    def prefix(self) -> Optional[str]:
        """
        Simple path prefix to GCS key.
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter
    def xml(self) -> Optional['outputs.GcsCollectionSourceXml']:
        return pulumi.get(self, "xml")


@pulumi.output_type
class GcsCollectionSourceCsv(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "columnNames":
            suggest = "column_names"
        elif key == "columnTypes":
            suggest = "column_types"
        elif key == "escapeChar":
            suggest = "escape_char"
        elif key == "firstLineAsColumnNames":
            suggest = "first_line_as_column_names"
        elif key == "quoteChar":
            suggest = "quote_char"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GcsCollectionSourceCsv. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GcsCollectionSourceCsv.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GcsCollectionSourceCsv.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 column_names: Optional[Sequence[str]] = None,
                 column_types: Optional[Sequence[str]] = None,
                 encoding: Optional[str] = None,
                 escape_char: Optional[str] = None,
                 first_line_as_column_names: Optional[bool] = None,
                 quote_char: Optional[str] = None,
                 separator: Optional[str] = None):
        """
        :param Sequence[str] column_names: The names of the columns.
        :param Sequence[str] column_types: The types of the columns.
        :param str encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param str escape_char: Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        :param bool first_line_as_column_names: If the first line in every object specifies the column names.
        :param str quote_char: Character within which a cell value is enclosed. Defaults to double quote.
        :param str separator: A single character that is the column separator.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if column_types is not None:
            pulumi.set(__self__, "column_types", column_types)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if escape_char is not None:
            pulumi.set(__self__, "escape_char", escape_char)
        if first_line_as_column_names is not None:
            pulumi.set(__self__, "first_line_as_column_names", first_line_as_column_names)
        if quote_char is not None:
            pulumi.set(__self__, "quote_char", quote_char)
        if separator is not None:
            pulumi.set(__self__, "separator", separator)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[Sequence[str]]:
        """
        The names of the columns.
        """
        return pulumi.get(self, "column_names")

    @property
    @pulumi.getter(name="columnTypes")
    def column_types(self) -> Optional[Sequence[str]]:
        """
        The types of the columns.
        """
        return pulumi.get(self, "column_types")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="escapeChar")
    def escape_char(self) -> Optional[str]:
        """
        Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        """
        return pulumi.get(self, "escape_char")

    @property
    @pulumi.getter(name="firstLineAsColumnNames")
    def first_line_as_column_names(self) -> Optional[bool]:
        """
        If the first line in every object specifies the column names.
        """
        return pulumi.get(self, "first_line_as_column_names")

    @property
    @pulumi.getter(name="quoteChar")
    def quote_char(self) -> Optional[str]:
        """
        Character within which a cell value is enclosed. Defaults to double quote.
        """
        return pulumi.get(self, "quote_char")

    @property
    @pulumi.getter
    def separator(self) -> Optional[str]:
        """
        A single character that is the column separator.
        """
        return pulumi.get(self, "separator")


@pulumi.output_type
class GcsCollectionSourceXml(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "attributePrefix":
            suggest = "attribute_prefix"
        elif key == "docTag":
            suggest = "doc_tag"
        elif key == "rootTag":
            suggest = "root_tag"
        elif key == "valueTag":
            suggest = "value_tag"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GcsCollectionSourceXml. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GcsCollectionSourceXml.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GcsCollectionSourceXml.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 attribute_prefix: Optional[str] = None,
                 doc_tag: Optional[str] = None,
                 encoding: Optional[str] = None,
                 root_tag: Optional[str] = None,
                 value_tag: Optional[str] = None):
        """
        :param str attribute_prefix: Tag to differentiate between attributes and elements.
        :param str doc_tag: Tags with which documents are identified
        :param str encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param str root_tag: Tag until which xml is ignored.
        :param str value_tag: Tag used for the value when there are attributes in the element having no child.
        """
        if attribute_prefix is not None:
            pulumi.set(__self__, "attribute_prefix", attribute_prefix)
        if doc_tag is not None:
            pulumi.set(__self__, "doc_tag", doc_tag)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if root_tag is not None:
            pulumi.set(__self__, "root_tag", root_tag)
        if value_tag is not None:
            pulumi.set(__self__, "value_tag", value_tag)

    @property
    @pulumi.getter(name="attributePrefix")
    def attribute_prefix(self) -> Optional[str]:
        """
        Tag to differentiate between attributes and elements.
        """
        return pulumi.get(self, "attribute_prefix")

    @property
    @pulumi.getter(name="docTag")
    def doc_tag(self) -> Optional[str]:
        """
        Tags with which documents are identified
        """
        return pulumi.get(self, "doc_tag")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="rootTag")
    def root_tag(self) -> Optional[str]:
        """
        Tag until which xml is ignored.
        """
        return pulumi.get(self, "root_tag")

    @property
    @pulumi.getter(name="valueTag")
    def value_tag(self) -> Optional[str]:
        """
        Tag used for the value when there are attributes in the element having no child.
        """
        return pulumi.get(self, "value_tag")


@pulumi.output_type
class KafkaCollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationName":
            suggest = "integration_name"
        elif key == "topicName":
            suggest = "topic_name"
        elif key == "consumerGroupId":
            suggest = "consumer_group_id"
        elif key == "offsetResetPolicy":
            suggest = "offset_reset_policy"
        elif key == "useV3":
            suggest = "use_v3"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KafkaCollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KafkaCollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KafkaCollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 integration_name: str,
                 topic_name: str,
                 consumer_group_id: Optional[str] = None,
                 offset_reset_policy: Optional[str] = None,
                 statuses: Optional[Sequence['outputs.KafkaCollectionSourceStatus']] = None,
                 use_v3: Optional[bool] = None):
        """
        :param str integration_name: The name of the Rockset Kafka integration.
        :param str topic_name: Name of Kafka topic to be tailed.
        :param str consumer_group_id: The Kafka consumer group Id being used.
        :param str offset_reset_policy: The offset reset policy. Possible values: LATEST, EARLIEST. Only valid with v3 collections.
        :param bool use_v3: Whether to use v3 integration. Required if the kafka integration uses v3.
        """
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "topic_name", topic_name)
        if consumer_group_id is not None:
            pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        if offset_reset_policy is not None:
            pulumi.set(__self__, "offset_reset_policy", offset_reset_policy)
        if statuses is not None:
            pulumi.set(__self__, "statuses", statuses)
        if use_v3 is not None:
            pulumi.set(__self__, "use_v3", use_v3)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset Kafka integration.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> str:
        """
        Name of Kafka topic to be tailed.
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> Optional[str]:
        """
        The Kafka consumer group Id being used.
        """
        return pulumi.get(self, "consumer_group_id")

    @property
    @pulumi.getter(name="offsetResetPolicy")
    def offset_reset_policy(self) -> Optional[str]:
        """
        The offset reset policy. Possible values: LATEST, EARLIEST. Only valid with v3 collections.
        """
        return pulumi.get(self, "offset_reset_policy")

    @property
    @pulumi.getter
    def statuses(self) -> Optional[Sequence['outputs.KafkaCollectionSourceStatus']]:
        return pulumi.get(self, "statuses")

    @property
    @pulumi.getter(name="useV3")
    def use_v3(self) -> Optional[bool]:
        """
        Whether to use v3 integration. Required if the kafka integration uses v3.
        """
        return pulumi.get(self, "use_v3")


@pulumi.output_type
class KafkaCollectionSourceStatus(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "documentsProcessed":
            suggest = "documents_processed"
        elif key == "lastConsumedTime":
            suggest = "last_consumed_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KafkaCollectionSourceStatus. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KafkaCollectionSourceStatus.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KafkaCollectionSourceStatus.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 documents_processed: Optional[int] = None,
                 last_consumed_time: Optional[str] = None,
                 partitions: Optional[Sequence['outputs.KafkaCollectionSourceStatusPartition']] = None,
                 state: Optional[str] = None):
        if documents_processed is not None:
            pulumi.set(__self__, "documents_processed", documents_processed)
        if last_consumed_time is not None:
            pulumi.set(__self__, "last_consumed_time", last_consumed_time)
        if partitions is not None:
            pulumi.set(__self__, "partitions", partitions)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="documentsProcessed")
    def documents_processed(self) -> Optional[int]:
        return pulumi.get(self, "documents_processed")

    @property
    @pulumi.getter(name="lastConsumedTime")
    def last_consumed_time(self) -> Optional[str]:
        return pulumi.get(self, "last_consumed_time")

    @property
    @pulumi.getter
    def partitions(self) -> Optional[Sequence['outputs.KafkaCollectionSourceStatusPartition']]:
        return pulumi.get(self, "partitions")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        return pulumi.get(self, "state")


@pulumi.output_type
class KafkaCollectionSourceStatusPartition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "offsetLag":
            suggest = "offset_lag"
        elif key == "partitionNumber":
            suggest = "partition_number"
        elif key == "partitionOffset":
            suggest = "partition_offset"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KafkaCollectionSourceStatusPartition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KafkaCollectionSourceStatusPartition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KafkaCollectionSourceStatusPartition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 offset_lag: Optional[int] = None,
                 partition_number: Optional[int] = None,
                 partition_offset: Optional[int] = None):
        if offset_lag is not None:
            pulumi.set(__self__, "offset_lag", offset_lag)
        if partition_number is not None:
            pulumi.set(__self__, "partition_number", partition_number)
        if partition_offset is not None:
            pulumi.set(__self__, "partition_offset", partition_offset)

    @property
    @pulumi.getter(name="offsetLag")
    def offset_lag(self) -> Optional[int]:
        return pulumi.get(self, "offset_lag")

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> Optional[int]:
        return pulumi.get(self, "partition_number")

    @property
    @pulumi.getter(name="partitionOffset")
    def partition_offset(self) -> Optional[int]:
        return pulumi.get(self, "partition_offset")


@pulumi.output_type
class KinesisCollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationName":
            suggest = "integration_name"
        elif key == "streamName":
            suggest = "stream_name"
        elif key == "awsRegion":
            suggest = "aws_region"
        elif key == "dmsPrimaryKeys":
            suggest = "dms_primary_keys"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KinesisCollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KinesisCollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KinesisCollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 format: str,
                 integration_name: str,
                 stream_name: str,
                 aws_region: Optional[str] = None,
                 dms_primary_keys: Optional[Sequence[str]] = None):
        """
        :param str format: Format of the data. One of: json, mysql, postgres. dms*primary*keys list can only be set for mysql or postgres.
        :param str integration_name: The name of the Rockset Kinesis integration.
        :param str stream_name: Name of Kinesis stream.
        :param str aws_region: AWS region name for the Kinesis stream, by default us-west-2 is used
        :param Sequence[str] dms_primary_keys: Set of fields that correspond to a DMS primary key. Can only be set if format is mysql or postgres.
        """
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "stream_name", stream_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if dms_primary_keys is not None:
            pulumi.set(__self__, "dms_primary_keys", dms_primary_keys)

    @property
    @pulumi.getter
    def format(self) -> str:
        """
        Format of the data. One of: json, mysql, postgres. dms*primary*keys list can only be set for mysql or postgres.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset Kinesis integration.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter(name="streamName")
    def stream_name(self) -> str:
        """
        Name of Kinesis stream.
        """
        return pulumi.get(self, "stream_name")

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[str]:
        """
        AWS region name for the Kinesis stream, by default us-west-2 is used
        """
        return pulumi.get(self, "aws_region")

    @property
    @pulumi.getter(name="dmsPrimaryKeys")
    def dms_primary_keys(self) -> Optional[Sequence[str]]:
        """
        Set of fields that correspond to a DMS primary key. Can only be set if format is mysql or postgres.
        """
        return pulumi.get(self, "dms_primary_keys")


@pulumi.output_type
class MongodbCollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "collectionName":
            suggest = "collection_name"
        elif key == "databaseName":
            suggest = "database_name"
        elif key == "integrationName":
            suggest = "integration_name"
        elif key == "retrieveFullDocument":
            suggest = "retrieve_full_document"
        elif key == "scanEndTime":
            suggest = "scan_end_time"
        elif key == "scanRecordsProcessed":
            suggest = "scan_records_processed"
        elif key == "scanStartTime":
            suggest = "scan_start_time"
        elif key == "scanTotalRecords":
            suggest = "scan_total_records"
        elif key == "streamLastDeleteProcessedAt":
            suggest = "stream_last_delete_processed_at"
        elif key == "streamLastInsertProcessedAt":
            suggest = "stream_last_insert_processed_at"
        elif key == "streamLastUpdateProcessedAt":
            suggest = "stream_last_update_processed_at"
        elif key == "streamRecordsDeleted":
            suggest = "stream_records_deleted"
        elif key == "streamRecordsInserted":
            suggest = "stream_records_inserted"
        elif key == "streamRecordsUpdated":
            suggest = "stream_records_updated"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MongodbCollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MongodbCollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MongodbCollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 collection_name: str,
                 database_name: str,
                 integration_name: str,
                 retrieve_full_document: Optional[bool] = None,
                 scan_end_time: Optional[str] = None,
                 scan_records_processed: Optional[int] = None,
                 scan_start_time: Optional[str] = None,
                 scan_total_records: Optional[int] = None,
                 state: Optional[str] = None,
                 stream_last_delete_processed_at: Optional[str] = None,
                 stream_last_insert_processed_at: Optional[str] = None,
                 stream_last_update_processed_at: Optional[str] = None,
                 stream_records_deleted: Optional[int] = None,
                 stream_records_inserted: Optional[int] = None,
                 stream_records_updated: Optional[int] = None):
        """
        :param str collection_name: MongoDB collection name of the target collection.
        :param str database_name: MongoDB database name containing the target collection.
        :param str integration_name: The name of the Rockset MongoDB integration.
        :param str scan_end_time: MongoDB scan end time.
        :param int scan_records_processed: Number of records inserted using scan.
        :param str scan_start_time: MongoDB scan start time.
        :param int scan_total_records: Number of records in MongoDB table at time of scan.
        :param str state: State of current ingest for this table.
        :param str stream_last_delete_processed_at: ISO-8601 date when delete from source was last processed.
        :param str stream_last_insert_processed_at: ISO-8601 date when new insert from source was last processed.
        :param str stream_last_update_processed_at: ISO-8601 date when update from source was last processed.
        :param int stream_records_deleted: Number of new records deleted using stream.
        :param int stream_records_inserted: Number of new records inserted using stream.
        :param int stream_records_updated: Number of new records updated using stream.
        """
        pulumi.set(__self__, "collection_name", collection_name)
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "integration_name", integration_name)
        if retrieve_full_document is not None:
            pulumi.set(__self__, "retrieve_full_document", retrieve_full_document)
        if scan_end_time is not None:
            pulumi.set(__self__, "scan_end_time", scan_end_time)
        if scan_records_processed is not None:
            pulumi.set(__self__, "scan_records_processed", scan_records_processed)
        if scan_start_time is not None:
            pulumi.set(__self__, "scan_start_time", scan_start_time)
        if scan_total_records is not None:
            pulumi.set(__self__, "scan_total_records", scan_total_records)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stream_last_delete_processed_at is not None:
            pulumi.set(__self__, "stream_last_delete_processed_at", stream_last_delete_processed_at)
        if stream_last_insert_processed_at is not None:
            pulumi.set(__self__, "stream_last_insert_processed_at", stream_last_insert_processed_at)
        if stream_last_update_processed_at is not None:
            pulumi.set(__self__, "stream_last_update_processed_at", stream_last_update_processed_at)
        if stream_records_deleted is not None:
            pulumi.set(__self__, "stream_records_deleted", stream_records_deleted)
        if stream_records_inserted is not None:
            pulumi.set(__self__, "stream_records_inserted", stream_records_inserted)
        if stream_records_updated is not None:
            pulumi.set(__self__, "stream_records_updated", stream_records_updated)

    @property
    @pulumi.getter(name="collectionName")
    def collection_name(self) -> str:
        """
        MongoDB collection name of the target collection.
        """
        return pulumi.get(self, "collection_name")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> str:
        """
        MongoDB database name containing the target collection.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset MongoDB integration.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter(name="retrieveFullDocument")
    def retrieve_full_document(self) -> Optional[bool]:
        return pulumi.get(self, "retrieve_full_document")

    @property
    @pulumi.getter(name="scanEndTime")
    def scan_end_time(self) -> Optional[str]:
        """
        MongoDB scan end time.
        """
        return pulumi.get(self, "scan_end_time")

    @property
    @pulumi.getter(name="scanRecordsProcessed")
    def scan_records_processed(self) -> Optional[int]:
        """
        Number of records inserted using scan.
        """
        return pulumi.get(self, "scan_records_processed")

    @property
    @pulumi.getter(name="scanStartTime")
    def scan_start_time(self) -> Optional[str]:
        """
        MongoDB scan start time.
        """
        return pulumi.get(self, "scan_start_time")

    @property
    @pulumi.getter(name="scanTotalRecords")
    def scan_total_records(self) -> Optional[int]:
        """
        Number of records in MongoDB table at time of scan.
        """
        return pulumi.get(self, "scan_total_records")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        State of current ingest for this table.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="streamLastDeleteProcessedAt")
    def stream_last_delete_processed_at(self) -> Optional[str]:
        """
        ISO-8601 date when delete from source was last processed.
        """
        return pulumi.get(self, "stream_last_delete_processed_at")

    @property
    @pulumi.getter(name="streamLastInsertProcessedAt")
    def stream_last_insert_processed_at(self) -> Optional[str]:
        """
        ISO-8601 date when new insert from source was last processed.
        """
        return pulumi.get(self, "stream_last_insert_processed_at")

    @property
    @pulumi.getter(name="streamLastUpdateProcessedAt")
    def stream_last_update_processed_at(self) -> Optional[str]:
        """
        ISO-8601 date when update from source was last processed.
        """
        return pulumi.get(self, "stream_last_update_processed_at")

    @property
    @pulumi.getter(name="streamRecordsDeleted")
    def stream_records_deleted(self) -> Optional[int]:
        """
        Number of new records deleted using stream.
        """
        return pulumi.get(self, "stream_records_deleted")

    @property
    @pulumi.getter(name="streamRecordsInserted")
    def stream_records_inserted(self) -> Optional[int]:
        """
        Number of new records inserted using stream.
        """
        return pulumi.get(self, "stream_records_inserted")

    @property
    @pulumi.getter(name="streamRecordsUpdated")
    def stream_records_updated(self) -> Optional[int]:
        """
        Number of new records updated using stream.
        """
        return pulumi.get(self, "stream_records_updated")


@pulumi.output_type
class QueryLambdaSql(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultParameters":
            suggest = "default_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in QueryLambdaSql. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        QueryLambdaSql.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        QueryLambdaSql.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 query: str,
                 default_parameters: Optional[Sequence['outputs.QueryLambdaSqlDefaultParameter']] = None):
        pulumi.set(__self__, "query", query)
        if default_parameters is not None:
            pulumi.set(__self__, "default_parameters", default_parameters)

    @property
    @pulumi.getter
    def query(self) -> str:
        return pulumi.get(self, "query")

    @property
    @pulumi.getter(name="defaultParameters")
    def default_parameters(self) -> Optional[Sequence['outputs.QueryLambdaSqlDefaultParameter']]:
        return pulumi.get(self, "default_parameters")


@pulumi.output_type
class QueryLambdaSqlDefaultParameter(dict):
    def __init__(__self__, *,
                 name: str,
                 type: str,
                 value: str):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class RolePrivilege(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceName":
            suggest = "resource_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RolePrivilege. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RolePrivilege.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RolePrivilege.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 action: str,
                 cluster: Optional[str] = None,
                 resource_name: Optional[str] = None):
        """
        :param str action: The action allowed by this privilege.
        :param str cluster: Rockset cluster ID for which this action is allowed. Only valid for Workspace actions. Use '*ALL*' for actions which apply to all clusters.
        :param str resource_name: The resource on which this action is allowed. Defaults to 'All' if not specified.
        """
        pulumi.set(__self__, "action", action)
        if cluster is not None:
            pulumi.set(__self__, "cluster", cluster)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        The action allowed by this privilege.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def cluster(self) -> Optional[str]:
        """
        Rockset cluster ID for which this action is allowed. Only valid for Workspace actions. Use '*ALL*' for actions which apply to all clusters.
        """
        return pulumi.get(self, "cluster")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[str]:
        """
        The resource on which this action is allowed. Defaults to 'All' if not specified.
        """
        return pulumi.get(self, "resource_name")


@pulumi.output_type
class S3CollectionSource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationName":
            suggest = "integration_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in S3CollectionSource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        S3CollectionSource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        S3CollectionSource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket: str,
                 format: str,
                 integration_name: str,
                 csv: Optional['outputs.S3CollectionSourceCsv'] = None,
                 pattern: Optional[str] = None,
                 prefix: Optional[str] = None,
                 xml: Optional['outputs.S3CollectionSourceXml'] = None):
        """
        :param str bucket: S3 bucket containing the target data.
        :param str format: Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        :param str integration_name: The name of the Rockset S3 integration. If no S3 integration is provided only data in public S3 buckets are accessible.
        :param str pattern: Regex path pattern to S3 keys.
        :param str prefix: Simple path prefix to S3 keys.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        if csv is not None:
            pulumi.set(__self__, "csv", csv)
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)
        if xml is not None:
            pulumi.set(__self__, "xml", xml)

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        S3 bucket containing the target data.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def format(self) -> str:
        """
        Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> str:
        """
        The name of the Rockset S3 integration. If no S3 integration is provided only data in public S3 buckets are accessible.
        """
        return pulumi.get(self, "integration_name")

    @property
    @pulumi.getter
    def csv(self) -> Optional['outputs.S3CollectionSourceCsv']:
        return pulumi.get(self, "csv")

    @property
    @pulumi.getter
    def pattern(self) -> Optional[str]:
        """
        Regex path pattern to S3 keys.
        """
        return pulumi.get(self, "pattern")

    @property
    @pulumi.getter
    def prefix(self) -> Optional[str]:
        """
        Simple path prefix to S3 keys.
        """
        warnings.warn("""use pattern instead""", DeprecationWarning)
        pulumi.log.warn("""prefix is deprecated: use pattern instead""")

        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter
    def xml(self) -> Optional['outputs.S3CollectionSourceXml']:
        return pulumi.get(self, "xml")


@pulumi.output_type
class S3CollectionSourceCsv(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "columnNames":
            suggest = "column_names"
        elif key == "columnTypes":
            suggest = "column_types"
        elif key == "escapeChar":
            suggest = "escape_char"
        elif key == "firstLineAsColumnNames":
            suggest = "first_line_as_column_names"
        elif key == "quoteChar":
            suggest = "quote_char"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in S3CollectionSourceCsv. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        S3CollectionSourceCsv.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        S3CollectionSourceCsv.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 column_names: Optional[Sequence[str]] = None,
                 column_types: Optional[Sequence[str]] = None,
                 encoding: Optional[str] = None,
                 escape_char: Optional[str] = None,
                 first_line_as_column_names: Optional[bool] = None,
                 quote_char: Optional[str] = None,
                 separator: Optional[str] = None):
        """
        :param Sequence[str] column_names: The names of the columns.
        :param Sequence[str] column_types: The types of the columns.
        :param str encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param str escape_char: Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        :param bool first_line_as_column_names: If the first line in every object specifies the column names.
        :param str quote_char: Character within which a cell value is enclosed. Defaults to double quote.
        :param str separator: A single character that is the column separator.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if column_types is not None:
            pulumi.set(__self__, "column_types", column_types)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if escape_char is not None:
            pulumi.set(__self__, "escape_char", escape_char)
        if first_line_as_column_names is not None:
            pulumi.set(__self__, "first_line_as_column_names", first_line_as_column_names)
        if quote_char is not None:
            pulumi.set(__self__, "quote_char", quote_char)
        if separator is not None:
            pulumi.set(__self__, "separator", separator)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[Sequence[str]]:
        """
        The names of the columns.
        """
        return pulumi.get(self, "column_names")

    @property
    @pulumi.getter(name="columnTypes")
    def column_types(self) -> Optional[Sequence[str]]:
        """
        The types of the columns.
        """
        return pulumi.get(self, "column_types")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="escapeChar")
    def escape_char(self) -> Optional[str]:
        """
        Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        """
        return pulumi.get(self, "escape_char")

    @property
    @pulumi.getter(name="firstLineAsColumnNames")
    def first_line_as_column_names(self) -> Optional[bool]:
        """
        If the first line in every object specifies the column names.
        """
        return pulumi.get(self, "first_line_as_column_names")

    @property
    @pulumi.getter(name="quoteChar")
    def quote_char(self) -> Optional[str]:
        """
        Character within which a cell value is enclosed. Defaults to double quote.
        """
        return pulumi.get(self, "quote_char")

    @property
    @pulumi.getter
    def separator(self) -> Optional[str]:
        """
        A single character that is the column separator.
        """
        return pulumi.get(self, "separator")


@pulumi.output_type
class S3CollectionSourceXml(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "attributePrefix":
            suggest = "attribute_prefix"
        elif key == "docTag":
            suggest = "doc_tag"
        elif key == "rootTag":
            suggest = "root_tag"
        elif key == "valueTag":
            suggest = "value_tag"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in S3CollectionSourceXml. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        S3CollectionSourceXml.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        S3CollectionSourceXml.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 attribute_prefix: Optional[str] = None,
                 doc_tag: Optional[str] = None,
                 encoding: Optional[str] = None,
                 root_tag: Optional[str] = None,
                 value_tag: Optional[str] = None):
        """
        :param str attribute_prefix: Tag to differentiate between attributes and elements.
        :param str doc_tag: Tags with which documents are identified
        :param str encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param str root_tag: Tag until which xml is ignored.
        :param str value_tag: Tag used for the value when there are attributes in the element having no child.
        """
        if attribute_prefix is not None:
            pulumi.set(__self__, "attribute_prefix", attribute_prefix)
        if doc_tag is not None:
            pulumi.set(__self__, "doc_tag", doc_tag)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if root_tag is not None:
            pulumi.set(__self__, "root_tag", root_tag)
        if value_tag is not None:
            pulumi.set(__self__, "value_tag", value_tag)

    @property
    @pulumi.getter(name="attributePrefix")
    def attribute_prefix(self) -> Optional[str]:
        """
        Tag to differentiate between attributes and elements.
        """
        return pulumi.get(self, "attribute_prefix")

    @property
    @pulumi.getter(name="docTag")
    def doc_tag(self) -> Optional[str]:
        """
        Tags with which documents are identified
        """
        return pulumi.get(self, "doc_tag")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="rootTag")
    def root_tag(self) -> Optional[str]:
        """
        Tag until which xml is ignored.
        """
        return pulumi.get(self, "root_tag")

    @property
    @pulumi.getter(name="valueTag")
    def value_tag(self) -> Optional[str]:
        """
        Tag used for the value when there are attributes in the element having no child.
        """
        return pulumi.get(self, "value_tag")


@pulumi.output_type
class GetAccountClusterResult(dict):
    def __init__(__self__, *,
                 api_server: str,
                 aws_region: str,
                 type: str):
        pulumi.set(__self__, "api_server", api_server)
        pulumi.set(__self__, "aws_region", aws_region)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="apiServer")
    def api_server(self) -> str:
        return pulumi.get(self, "api_server")

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> str:
        return pulumi.get(self, "aws_region")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['CollectionMountArgs', 'CollectionMount']

@pulumi.input_type
class CollectionMountArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[str],
                 virtual_instance_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a CollectionMount resource.
        :param pulumi.Input[str] path: Collection path to be mounted, in the form workspace.collection
        :param pulumi.Input[str] virtual_instance_id: Virtual Instance id
        """
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "virtual_instance_id", virtual_instance_id)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        Collection path to be mounted, in the form workspace.collection
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="virtualInstanceId")
    def virtual_instance_id(self) -> pulumi.Input[str]:
        """
        Virtual Instance id
        """
        return pulumi.get(self, "virtual_instance_id")

    @virtual_instance_id.setter
    def virtual_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "virtual_instance_id", value)


@pulumi.input_type
class _CollectionMountState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 last_refresh_time: Optional[pulumi.Input[int]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 rrn: Optional[pulumi.Input[str]] = None,
                 snapshot_expiration_time: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 virtual_instance_id: Optional[pulumi.Input[str]] = None,
                 virtual_instance_rrn: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CollectionMount resources.
        :param pulumi.Input[str] created_at: ISO 8601 date when the mount was created.
        :param pulumi.Input[int] last_refresh_time: UNIX timestamp in milliseconds for most recent refresh. Not applicable for live mounts.
        :param pulumi.Input[str] path: Collection path to be mounted, in the form workspace.collection
        :param pulumi.Input[str] rrn: RRN of this mount.
        :param pulumi.Input[int] snapshot_expiration_time: UNIX timestamp in milliseconds when the snapshot expires.
        :param pulumi.Input[str] state: Mount state.
        :param pulumi.Input[str] virtual_instance_id: Virtual Instance id
        :param pulumi.Input[str] virtual_instance_rrn: Virtual Instance RRN
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if last_refresh_time is not None:
            pulumi.set(__self__, "last_refresh_time", last_refresh_time)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if rrn is not None:
            pulumi.set(__self__, "rrn", rrn)
        if snapshot_expiration_time is not None:
            pulumi.set(__self__, "snapshot_expiration_time", snapshot_expiration_time)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if virtual_instance_id is not None:
            pulumi.set(__self__, "virtual_instance_id", virtual_instance_id)
        if virtual_instance_rrn is not None:
            pulumi.set(__self__, "virtual_instance_rrn", virtual_instance_rrn)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        ISO 8601 date when the mount was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="lastRefreshTime")
    def last_refresh_time(self) -> Optional[pulumi.Input[int]]:
        """
        UNIX timestamp in milliseconds for most recent refresh. Not applicable for live mounts.
        """
        return pulumi.get(self, "last_refresh_time")

    @last_refresh_time.setter
    def last_refresh_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "last_refresh_time", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        Collection path to be mounted, in the form workspace.collection
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def rrn(self) -> Optional[pulumi.Input[str]]:
        """
        RRN of this mount.
        """
        return pulumi.get(self, "rrn")

    @rrn.setter
    def rrn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rrn", value)

    @property
    @pulumi.getter(name="snapshotExpirationTime")
    def snapshot_expiration_time(self) -> Optional[pulumi.Input[int]]:
        """
        UNIX timestamp in milliseconds when the snapshot expires.
        """
        return pulumi.get(self, "snapshot_expiration_time")

    @snapshot_expiration_time.setter
    def snapshot_expiration_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "snapshot_expiration_time", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Mount state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="virtualInstanceId")
    def virtual_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        Virtual Instance id
        """
        return pulumi.get(self, "virtual_instance_id")

    @virtual_instance_id.setter
    def virtual_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_instance_id", value)

    @property
    @pulumi.getter(name="virtualInstanceRrn")
    def virtual_instance_rrn(self) -> Optional[pulumi.Input[str]]:
        """
        Virtual Instance RRN
        """
        return pulumi.get(self, "virtual_instance_rrn")

    @virtual_instance_rrn.setter
    def virtual_instance_rrn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_instance_rrn", value)


class CollectionMount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 virtual_instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a collection mount.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        data = rockset.CollectionMount("data",
            virtual_instance_id=rockset_virtual_instance["secondary"]["id"],
            path="commons.data")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/collectionMount:CollectionMount demo 29e4a43c-fff4-4fe6-80e3-1ee57bc22e82
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] path: Collection path to be mounted, in the form workspace.collection
        :param pulumi.Input[str] virtual_instance_id: Virtual Instance id
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CollectionMountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a collection mount.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        data = rockset.CollectionMount("data",
            virtual_instance_id=rockset_virtual_instance["secondary"]["id"],
            path="commons.data")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/collectionMount:CollectionMount demo 29e4a43c-fff4-4fe6-80e3-1ee57bc22e82
        ```

        :param str resource_name: The name of the resource.
        :param CollectionMountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CollectionMountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 virtual_instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CollectionMountArgs.__new__(CollectionMountArgs)

            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            if virtual_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'virtual_instance_id'")
            __props__.__dict__["virtual_instance_id"] = virtual_instance_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["last_refresh_time"] = None
            __props__.__dict__["rrn"] = None
            __props__.__dict__["snapshot_expiration_time"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["virtual_instance_rrn"] = None
        super(CollectionMount, __self__).__init__(
            'rockset:index/collectionMount:CollectionMount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            last_refresh_time: Optional[pulumi.Input[int]] = None,
            path: Optional[pulumi.Input[str]] = None,
            rrn: Optional[pulumi.Input[str]] = None,
            snapshot_expiration_time: Optional[pulumi.Input[int]] = None,
            state: Optional[pulumi.Input[str]] = None,
            virtual_instance_id: Optional[pulumi.Input[str]] = None,
            virtual_instance_rrn: Optional[pulumi.Input[str]] = None) -> 'CollectionMount':
        """
        Get an existing CollectionMount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: ISO 8601 date when the mount was created.
        :param pulumi.Input[int] last_refresh_time: UNIX timestamp in milliseconds for most recent refresh. Not applicable for live mounts.
        :param pulumi.Input[str] path: Collection path to be mounted, in the form workspace.collection
        :param pulumi.Input[str] rrn: RRN of this mount.
        :param pulumi.Input[int] snapshot_expiration_time: UNIX timestamp in milliseconds when the snapshot expires.
        :param pulumi.Input[str] state: Mount state.
        :param pulumi.Input[str] virtual_instance_id: Virtual Instance id
        :param pulumi.Input[str] virtual_instance_rrn: Virtual Instance RRN
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CollectionMountState.__new__(_CollectionMountState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["last_refresh_time"] = last_refresh_time
        __props__.__dict__["path"] = path
        __props__.__dict__["rrn"] = rrn
        __props__.__dict__["snapshot_expiration_time"] = snapshot_expiration_time
        __props__.__dict__["state"] = state
        __props__.__dict__["virtual_instance_id"] = virtual_instance_id
        __props__.__dict__["virtual_instance_rrn"] = virtual_instance_rrn
        return CollectionMount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        ISO 8601 date when the mount was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="lastRefreshTime")
    def last_refresh_time(self) -> pulumi.Output[int]:
        """
        UNIX timestamp in milliseconds for most recent refresh. Not applicable for live mounts.
        """
        return pulumi.get(self, "last_refresh_time")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[str]:
        """
        Collection path to be mounted, in the form workspace.collection
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def rrn(self) -> pulumi.Output[str]:
        """
        RRN of this mount.
        """
        return pulumi.get(self, "rrn")

    @property
    @pulumi.getter(name="snapshotExpirationTime")
    def snapshot_expiration_time(self) -> pulumi.Output[int]:
        """
        UNIX timestamp in milliseconds when the snapshot expires.
        """
        return pulumi.get(self, "snapshot_expiration_time")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Mount state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="virtualInstanceId")
    def virtual_instance_id(self) -> pulumi.Output[str]:
        """
        Virtual Instance id
        """
        return pulumi.get(self, "virtual_instance_id")

    @property
    @pulumi.getter(name="virtualInstanceRrn")
    def virtual_instance_rrn(self) -> pulumi.Output[str]:
        """
        Virtual Instance RRN
        """
        return pulumi.get(self, "virtual_instance_rrn")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['KafkaIntegrationArgs', 'KafkaIntegration']

@pulumi.input_type
class KafkaIntegrationArgs:
    def __init__(__self__, *,
                 bootstrap_servers: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kafka_data_format: Optional[pulumi.Input[str]] = None,
                 kafka_topic_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 schema_registry_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 security_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 use_v3: Optional[pulumi.Input[bool]] = None,
                 wait_for_integration: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a KafkaIntegration resource.
        :param pulumi.Input[str] bootstrap_servers: The Kafka bootstrap server url(s). Required only for V3 integration.
        :param pulumi.Input[str] connection_string: Kafka connection string.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] kafka_data_format: The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] kafka_topic_names: Kafka topics to tail.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] schema_registry_config: Kafka configuration for schema registry. Required only for V3 integration.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] security_config: Kafka security configurations. Required only for V3 integration.
        :param pulumi.Input[bool] use_v3: Use v3 for Confluent Cloud.
        :param pulumi.Input[bool] wait_for_integration: Wait until the integration is active.
        """
        if bootstrap_servers is not None:
            pulumi.set(__self__, "bootstrap_servers", bootstrap_servers)
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kafka_data_format is not None:
            pulumi.set(__self__, "kafka_data_format", kafka_data_format)
        if kafka_topic_names is not None:
            pulumi.set(__self__, "kafka_topic_names", kafka_topic_names)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if schema_registry_config is not None:
            pulumi.set(__self__, "schema_registry_config", schema_registry_config)
        if security_config is not None:
            pulumi.set(__self__, "security_config", security_config)
        if use_v3 is not None:
            pulumi.set(__self__, "use_v3", use_v3)
        if wait_for_integration is not None:
            pulumi.set(__self__, "wait_for_integration", wait_for_integration)

    @property
    @pulumi.getter(name="bootstrapServers")
    def bootstrap_servers(self) -> Optional[pulumi.Input[str]]:
        """
        The Kafka bootstrap server url(s). Required only for V3 integration.
        """
        return pulumi.get(self, "bootstrap_servers")

    @bootstrap_servers.setter
    def bootstrap_servers(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bootstrap_servers", value)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        Kafka connection string.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kafkaDataFormat")
    def kafka_data_format(self) -> Optional[pulumi.Input[str]]:
        """
        The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        """
        return pulumi.get(self, "kafka_data_format")

    @kafka_data_format.setter
    def kafka_data_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kafka_data_format", value)

    @property
    @pulumi.getter(name="kafkaTopicNames")
    def kafka_topic_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Kafka topics to tail.
        """
        return pulumi.get(self, "kafka_topic_names")

    @kafka_topic_names.setter
    def kafka_topic_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "kafka_topic_names", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="schemaRegistryConfig")
    def schema_registry_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Kafka configuration for schema registry. Required only for V3 integration.
        """
        return pulumi.get(self, "schema_registry_config")

    @schema_registry_config.setter
    def schema_registry_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "schema_registry_config", value)

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Kafka security configurations. Required only for V3 integration.
        """
        return pulumi.get(self, "security_config")

    @security_config.setter
    def security_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "security_config", value)

    @property
    @pulumi.getter(name="useV3")
    def use_v3(self) -> Optional[pulumi.Input[bool]]:
        """
        Use v3 for Confluent Cloud.
        """
        return pulumi.get(self, "use_v3")

    @use_v3.setter
    def use_v3(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_v3", value)

    @property
    @pulumi.getter(name="waitForIntegration")
    def wait_for_integration(self) -> Optional[pulumi.Input[bool]]:
        """
        Wait until the integration is active.
        """
        return pulumi.get(self, "wait_for_integration")

    @wait_for_integration.setter
    def wait_for_integration(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wait_for_integration", value)


@pulumi.input_type
class _KafkaIntegrationState:
    def __init__(__self__, *,
                 bootstrap_servers: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kafka_data_format: Optional[pulumi.Input[str]] = None,
                 kafka_topic_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 schema_registry_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 security_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 use_v3: Optional[pulumi.Input[bool]] = None,
                 wait_for_integration: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering KafkaIntegration resources.
        :param pulumi.Input[str] bootstrap_servers: The Kafka bootstrap server url(s). Required only for V3 integration.
        :param pulumi.Input[str] connection_string: Kafka connection string.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] kafka_data_format: The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] kafka_topic_names: Kafka topics to tail.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] schema_registry_config: Kafka configuration for schema registry. Required only for V3 integration.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] security_config: Kafka security configurations. Required only for V3 integration.
        :param pulumi.Input[bool] use_v3: Use v3 for Confluent Cloud.
        :param pulumi.Input[bool] wait_for_integration: Wait until the integration is active.
        """
        if bootstrap_servers is not None:
            pulumi.set(__self__, "bootstrap_servers", bootstrap_servers)
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kafka_data_format is not None:
            pulumi.set(__self__, "kafka_data_format", kafka_data_format)
        if kafka_topic_names is not None:
            pulumi.set(__self__, "kafka_topic_names", kafka_topic_names)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if schema_registry_config is not None:
            pulumi.set(__self__, "schema_registry_config", schema_registry_config)
        if security_config is not None:
            pulumi.set(__self__, "security_config", security_config)
        if use_v3 is not None:
            pulumi.set(__self__, "use_v3", use_v3)
        if wait_for_integration is not None:
            pulumi.set(__self__, "wait_for_integration", wait_for_integration)

    @property
    @pulumi.getter(name="bootstrapServers")
    def bootstrap_servers(self) -> Optional[pulumi.Input[str]]:
        """
        The Kafka bootstrap server url(s). Required only for V3 integration.
        """
        return pulumi.get(self, "bootstrap_servers")

    @bootstrap_servers.setter
    def bootstrap_servers(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bootstrap_servers", value)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        Kafka connection string.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kafkaDataFormat")
    def kafka_data_format(self) -> Optional[pulumi.Input[str]]:
        """
        The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        """
        return pulumi.get(self, "kafka_data_format")

    @kafka_data_format.setter
    def kafka_data_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kafka_data_format", value)

    @property
    @pulumi.getter(name="kafkaTopicNames")
    def kafka_topic_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Kafka topics to tail.
        """
        return pulumi.get(self, "kafka_topic_names")

    @kafka_topic_names.setter
    def kafka_topic_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "kafka_topic_names", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="schemaRegistryConfig")
    def schema_registry_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Kafka configuration for schema registry. Required only for V3 integration.
        """
        return pulumi.get(self, "schema_registry_config")

    @schema_registry_config.setter
    def schema_registry_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "schema_registry_config", value)

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Kafka security configurations. Required only for V3 integration.
        """
        return pulumi.get(self, "security_config")

    @security_config.setter
    def security_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "security_config", value)

    @property
    @pulumi.getter(name="useV3")
    def use_v3(self) -> Optional[pulumi.Input[bool]]:
        """
        Use v3 for Confluent Cloud.
        """
        return pulumi.get(self, "use_v3")

    @use_v3.setter
    def use_v3(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_v3", value)

    @property
    @pulumi.getter(name="waitForIntegration")
    def wait_for_integration(self) -> Optional[pulumi.Input[bool]]:
        """
        Wait until the integration is active.
        """
        return pulumi.get(self, "wait_for_integration")

    @wait_for_integration.setter
    def wait_for_integration(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wait_for_integration", value)


class KafkaIntegration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bootstrap_servers: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kafka_data_format: Optional[pulumi.Input[str]] = None,
                 kafka_topic_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 schema_registry_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 security_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 use_v3: Optional[pulumi.Input[bool]] = None,
                 wait_for_integration: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_null as null
        import pulumi_rockset as rockset

        config = pulumi.Config()
        rockset_apiserver = config.get("rocksetApiserver")
        if rockset_apiserver is None:
            rockset_apiserver = "https://api.usw2a1.rockset.com"
        kafka_connect = config.get("kafkaConnect")
        if kafka_connect is None:
            kafka_connect = "localhost:8083"
        topics = config.require_object("topics")
        max_tasks = config.get_float("maxTasks")
        if max_tasks is None:
            max_tasks = 10
        local = rockset.KafkaIntegration("local",
            description="Integration to ingest from a local kafka.",
            kafka_data_format="JSON",
            kafka_topic_names=[
                "foo",
                "bar",
            ],
            wait_for_integration=False)
        configure_kafka_connect = null.Resource("configure-kafka-connect")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bootstrap_servers: The Kafka bootstrap server url(s). Required only for V3 integration.
        :param pulumi.Input[str] connection_string: Kafka connection string.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] kafka_data_format: The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] kafka_topic_names: Kafka topics to tail.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] schema_registry_config: Kafka configuration for schema registry. Required only for V3 integration.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] security_config: Kafka security configurations. Required only for V3 integration.
        :param pulumi.Input[bool] use_v3: Use v3 for Confluent Cloud.
        :param pulumi.Input[bool] wait_for_integration: Wait until the integration is active.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[KafkaIntegrationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_null as null
        import pulumi_rockset as rockset

        config = pulumi.Config()
        rockset_apiserver = config.get("rocksetApiserver")
        if rockset_apiserver is None:
            rockset_apiserver = "https://api.usw2a1.rockset.com"
        kafka_connect = config.get("kafkaConnect")
        if kafka_connect is None:
            kafka_connect = "localhost:8083"
        topics = config.require_object("topics")
        max_tasks = config.get_float("maxTasks")
        if max_tasks is None:
            max_tasks = 10
        local = rockset.KafkaIntegration("local",
            description="Integration to ingest from a local kafka.",
            kafka_data_format="JSON",
            kafka_topic_names=[
                "foo",
                "bar",
            ],
            wait_for_integration=False)
        configure_kafka_connect = null.Resource("configure-kafka-connect")
        ```

        :param str resource_name: The name of the resource.
        :param KafkaIntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KafkaIntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bootstrap_servers: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kafka_data_format: Optional[pulumi.Input[str]] = None,
                 kafka_topic_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 schema_registry_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 security_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 use_v3: Optional[pulumi.Input[bool]] = None,
                 wait_for_integration: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KafkaIntegrationArgs.__new__(KafkaIntegrationArgs)

            __props__.__dict__["bootstrap_servers"] = bootstrap_servers
            __props__.__dict__["connection_string"] = connection_string
            __props__.__dict__["description"] = description
            __props__.__dict__["kafka_data_format"] = kafka_data_format
            __props__.__dict__["kafka_topic_names"] = kafka_topic_names
            __props__.__dict__["name"] = name
            __props__.__dict__["schema_registry_config"] = schema_registry_config
            __props__.__dict__["security_config"] = security_config
            __props__.__dict__["use_v3"] = use_v3
            __props__.__dict__["wait_for_integration"] = wait_for_integration
        super(KafkaIntegration, __self__).__init__(
            'rockset:index/kafkaIntegration:KafkaIntegration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bootstrap_servers: Optional[pulumi.Input[str]] = None,
            connection_string: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            kafka_data_format: Optional[pulumi.Input[str]] = None,
            kafka_topic_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            schema_registry_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            security_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            use_v3: Optional[pulumi.Input[bool]] = None,
            wait_for_integration: Optional[pulumi.Input[bool]] = None) -> 'KafkaIntegration':
        """
        Get an existing KafkaIntegration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bootstrap_servers: The Kafka bootstrap server url(s). Required only for V3 integration.
        :param pulumi.Input[str] connection_string: Kafka connection string.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] kafka_data_format: The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] kafka_topic_names: Kafka topics to tail.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] schema_registry_config: Kafka configuration for schema registry. Required only for V3 integration.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] security_config: Kafka security configurations. Required only for V3 integration.
        :param pulumi.Input[bool] use_v3: Use v3 for Confluent Cloud.
        :param pulumi.Input[bool] wait_for_integration: Wait until the integration is active.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KafkaIntegrationState.__new__(_KafkaIntegrationState)

        __props__.__dict__["bootstrap_servers"] = bootstrap_servers
        __props__.__dict__["connection_string"] = connection_string
        __props__.__dict__["description"] = description
        __props__.__dict__["kafka_data_format"] = kafka_data_format
        __props__.__dict__["kafka_topic_names"] = kafka_topic_names
        __props__.__dict__["name"] = name
        __props__.__dict__["schema_registry_config"] = schema_registry_config
        __props__.__dict__["security_config"] = security_config
        __props__.__dict__["use_v3"] = use_v3
        __props__.__dict__["wait_for_integration"] = wait_for_integration
        return KafkaIntegration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bootstrapServers")
    def bootstrap_servers(self) -> pulumi.Output[Optional[str]]:
        """
        The Kafka bootstrap server url(s). Required only for V3 integration.
        """
        return pulumi.get(self, "bootstrap_servers")

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> pulumi.Output[str]:
        """
        Kafka connection string.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="kafkaDataFormat")
    def kafka_data_format(self) -> pulumi.Output[Optional[str]]:
        """
        The format of the Kafka topics being tailed. Possible values: JSON, AVRO.
        """
        return pulumi.get(self, "kafka_data_format")

    @property
    @pulumi.getter(name="kafkaTopicNames")
    def kafka_topic_names(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Kafka topics to tail.
        """
        return pulumi.get(self, "kafka_topic_names")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="schemaRegistryConfig")
    def schema_registry_config(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Kafka configuration for schema registry. Required only for V3 integration.
        """
        return pulumi.get(self, "schema_registry_config")

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Kafka security configurations. Required only for V3 integration.
        """
        return pulumi.get(self, "security_config")

    @property
    @pulumi.getter(name="useV3")
    def use_v3(self) -> pulumi.Output[Optional[bool]]:
        """
        Use v3 for Confluent Cloud.
        """
        return pulumi.get(self, "use_v3")

    @property
    @pulumi.getter(name="waitForIntegration")
    def wait_for_integration(self) -> pulumi.Output[Optional[bool]]:
        """
        Wait until the integration is active.
        """
        return pulumi.get(self, "wait_for_integration")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 roles: pulumi.Input[Sequence[pulumi.Input[str]]],
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] email: Email address of the user. Also used to identify the user.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        :param pulumi.Input[str] first_name: User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[str] last_name: User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "roles", roles)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        Email address of the user. Also used to identify the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[str] created_at: The ISO-8601 time of when the user was created.
        :param pulumi.Input[str] email: Email address of the user. Also used to identify the user.
        :param pulumi.Input[str] first_name: User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[str] last_name: User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        :param pulumi.Input[str] state: State of the user, either NEW or ACTIVE.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO-8601 time of when the user was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        Email address of the user. Also used to identify the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        State of the user, either NEW or ACTIVE.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages a Rockset User.

        First and last name can only be managed for users who have accepted the invite,
        i.e. when the state is ACCEPTED.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: Email address of the user. Also used to identify the user.
        :param pulumi.Input[str] first_name: User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[str] last_name: User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset User.

        First and last name can only be managed for users who have accepted the invite,
        i.e. when the state is ACCEPTED.

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["first_name"] = first_name
            __props__.__dict__["last_name"] = last_name
            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
            __props__.__dict__["created_at"] = None
            __props__.__dict__["state"] = None
        super(User, __self__).__init__(
            'rockset:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            email: Optional[pulumi.Input[str]] = None,
            first_name: Optional[pulumi.Input[str]] = None,
            last_name: Optional[pulumi.Input[str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: The ISO-8601 time of when the user was created.
        :param pulumi.Input[str] email: Email address of the user. Also used to identify the user.
        :param pulumi.Input[str] first_name: User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[str] last_name: User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        :param pulumi.Input[str] state: State of the user, either NEW or ACTIVE.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["email"] = email
        __props__.__dict__["first_name"] = first_name
        __props__.__dict__["last_name"] = last_name
        __props__.__dict__["roles"] = roles
        __props__.__dict__["state"] = state
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The ISO-8601 time of when the user was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        Email address of the user. Also used to identify the user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Output[Optional[str]]:
        """
        User's first name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Output[Optional[str]]:
        """
        User's last name. This can only be set once the state is ACTIVE, i.e after the user has accepted the invite.
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[str]]:
        """
        List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        State of the user, either NEW or ACTIVE.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ViewArgs', 'View']

@pulumi.input_type
class ViewArgs:
    def __init__(__self__, *,
                 query: pulumi.Input[str],
                 workspace: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a View resource.
        :param pulumi.Input[str] query: SQL query used for thw view.
        :param pulumi.Input[str] workspace: Workspace name.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        """
        pulumi.set(__self__, "query", query)
        pulumi.set(__self__, "workspace", workspace)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def query(self) -> pulumi.Input[str]:
        """
        SQL query used for thw view.
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[str]):
        pulumi.set(self, "query", value)

    @property
    @pulumi.getter
    def workspace(self) -> pulumi.Input[str]:
        """
        Workspace name.
        """
        return pulumi.get(self, "workspace")

    @workspace.setter
    def workspace(self, value: pulumi.Input[str]):
        pulumi.set(self, "workspace", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ViewState:
    def __init__(__self__, *,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering View resources.
        :param pulumi.Input[str] created_by: The user who created the view.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query: SQL query used for thw view.
        :param pulumi.Input[str] workspace: Workspace name.
        """
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if query is not None:
            pulumi.set(__self__, "query", query)
        if workspace is not None:
            pulumi.set(__self__, "workspace", workspace)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user who created the view.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def query(self) -> Optional[pulumi.Input[str]]:
        """
        SQL query used for thw view.
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "query", value)

    @property
    @pulumi.getter
    def workspace(self) -> Optional[pulumi.Input[str]]:
        """
        Workspace name.
        """
        return pulumi.get(self, "workspace")

    @workspace.setter
    def workspace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "workspace", value)


class View(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        sample = rockset.Workspace("sample", description="sample datasets")
        public = rockset.S3Integration("public",
            description="Integration to access Rockset's public datasets",
            aws_role_arn="arn:aws:iam::469279130686:role/rockset-public-datasets")
        cities = rockset.S3Collection("cities",
            workspace=sample.name,
            sources=[rockset.S3CollectionSourceArgs(
                bucket="rockset-public-datasets",
                integration_name=public.name,
                pattern="cities/*.json",
                format="json",
            )])
        brazil = rockset.View("brazil",
            query="SELECT * FROM sample.cities c WHERE c.fields.country_code = 'BR'",
            workspace=sample.name,
            opts=pulumi.ResourceOptions(depends_on=[cities]))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query: SQL query used for thw view.
        :param pulumi.Input[str] workspace: Workspace name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ViewArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        sample = rockset.Workspace("sample", description="sample datasets")
        public = rockset.S3Integration("public",
            description="Integration to access Rockset's public datasets",
            aws_role_arn="arn:aws:iam::469279130686:role/rockset-public-datasets")
        cities = rockset.S3Collection("cities",
            workspace=sample.name,
            sources=[rockset.S3CollectionSourceArgs(
                bucket="rockset-public-datasets",
                integration_name=public.name,
                pattern="cities/*.json",
                format="json",
            )])
        brazil = rockset.View("brazil",
            query="SELECT * FROM sample.cities c WHERE c.fields.country_code = 'BR'",
            workspace=sample.name,
            opts=pulumi.ResourceOptions(depends_on=[cities]))
        ```

        :param str resource_name: The name of the resource.
        :param ViewArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ViewArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ViewArgs.__new__(ViewArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if query is None and not opts.urn:
                raise TypeError("Missing required property 'query'")
            __props__.__dict__["query"] = query
            if workspace is None and not opts.urn:
                raise TypeError("Missing required property 'workspace'")
            __props__.__dict__["workspace"] = workspace
            __props__.__dict__["created_by"] = None
        super(View, __self__).__init__(
            'rockset:index/view:View',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            query: Optional[pulumi.Input[str]] = None,
            workspace: Optional[pulumi.Input[str]] = None) -> 'View':
        """
        Get an existing View resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_by: The user who created the view.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query: SQL query used for thw view.
        :param pulumi.Input[str] workspace: Workspace name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ViewState.__new__(_ViewState)

        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["query"] = query
        __props__.__dict__["workspace"] = workspace
        return View(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        The user who created the view.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Unique name for the view in the workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def query(self) -> pulumi.Output[str]:
        """
        SQL query used for thw view.
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter
    def workspace(self) -> pulumi.Output[str]:
        """
        Workspace name.
        """
        return pulumi.get(self, "workspace")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['WorkspaceArgs', 'Workspace']

@pulumi.input_type
class WorkspaceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Workspace resource.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _WorkspaceState:
    def __init__(__self__, *,
                 collection_count: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Workspace resources.
        :param pulumi.Input[int] collection_count: Number of collections in the workspace.
        :param pulumi.Input[str] created_at: Created at in ISO-8601.
        :param pulumi.Input[str] created_by: The user who created the workspace.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        if collection_count is not None:
            pulumi.set(__self__, "collection_count", collection_count)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="collectionCount")
    def collection_count(self) -> Optional[pulumi.Input[int]]:
        """
        Number of collections in the workspace.
        """
        return pulumi.get(self, "collection_count")

    @collection_count.setter
    def collection_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "collection_count", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Created at in ISO-8601.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user who created the workspace.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Workspace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Rockset workspace, which can hold collections, query lambdas and views.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        demo = rockset.Workspace("demo", description="a workspace for demo collections")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/workspace:Workspace demo demo
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[WorkspaceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset workspace, which can hold collections, query lambdas and views.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        demo = rockset.Workspace("demo", description="a workspace for demo collections")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/workspace:Workspace demo demo
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceArgs.__new__(WorkspaceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["collection_count"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
        super(Workspace, __self__).__init__(
            'rockset:index/workspace:Workspace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            collection_count: Optional[pulumi.Input[int]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Workspace':
        """
        Get an existing Workspace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] collection_count: Number of collections in the workspace.
        :param pulumi.Input[str] created_at: Created at in ISO-8601.
        :param pulumi.Input[str] created_by: The user who created the workspace.
        :param pulumi.Input[str] description: Text describing the collection.
        :param pulumi.Input[str] name: Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceState.__new__(_WorkspaceState)

        __props__.__dict__["collection_count"] = collection_count
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        return Workspace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="collectionCount")
    def collection_count(self) -> pulumi.Output[int]:
        """
        Number of collections in the workspace.
        """
        return pulumi.get(self, "collection_count")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Created at in ISO-8601.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        The user who created the workspace.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Text describing the collection.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Unique identifier for workspace. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetWorkspaceResult',
    'AwaitableGetWorkspaceResult',
    'get_workspace',
    'get_workspace_output',
]

@pulumi.output_type
class GetWorkspaceResult:
    """
    A collection of values returned by getWorkspace.
    """
    def __init__(__self__, collection_count=None, created_at=None, created_by=None, description=None, id=None, name=None):
        if collection_count and not isinstance(collection_count, int):
            raise TypeError("Expected argument 'collection_count' to be a int")
        pulumi.set(__self__, "collection_count", collection_count)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="collectionCount")
    def collection_count(self) -> int:
        """
        Number of collections in the workspace.
        """
        return pulumi.get(self, "collection_count")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Created at in ISO-8601.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        Created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Workspace description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The workspace `name`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Workspace name.
        """
        return pulumi.get(self, "name")


class AwaitableGetWorkspaceResult(GetWorkspaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceResult(
            collection_count=self.collection_count,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            id=self.id,
            name=self.name)


def get_workspace(name: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceResult:
    """
    Gets information about a workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rockset as rockset

    demo = rockset.get_workspace(name="demo")
    ```


    :param str name: Workspace name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rockset:index/getWorkspace:getWorkspace', __args__, opts=opts, typ=GetWorkspaceResult).value

    return AwaitableGetWorkspaceResult(
        collection_count=pulumi.get(__ret__, 'collection_count'),
        created_at=pulumi.get(__ret__, 'created_at'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))


@_utilities.lift_output_func(get_workspace)
def get_workspace_output(name: Optional[pulumi.Input[str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetWorkspaceResult]:
    """
    Gets information about a workspace.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rockset as rockset

    demo = rockset.get_workspace(name="demo")
    ```


    :param str name: Workspace name.
    """
    ...
